The deprecated ``api_helpers`` was removed in favor of the ``app_helpers``
module. In addition, the deprecated ``body``
attributes for the :class:`~falcon.Response`,
:class:`asgi.Response <falcon.asgi.Response>`,
and :class:`~falcon.HTTPStatus` classes.
